@@ -25,7 +25,7 @@ def open_ini(openpath):
     root = []
     secn = 0
     
-    with open(openpath) as f:
+    with open(openpath,encoding='utf-8') as f:
         for line in f:
 
             line = line.rstrip("\n")
@@ -205,5 +205,5 @@ def ini_del(inipath,section="",item=""):
 
 
 def file_write(path,text):
-    with open(path, mode='w') as fw:
+    with open(path, mode='w',encoding='utf-8') as fw:
         fw.write(text+"\n\n")
